pub enum AdvancedCommerceEffective {
Immediately,
NextBillCycle,
NotSupported(String),
}Expand description
A string value that indicates when a requested change to an auto-renewable subscription goes into effect.
Variants
Immediately
NextBillCycle
NotSupported(String)
A value the App Store sent that this version of the library does not support, preserved as received.