pub enum AdvancedCommerceReason {
Upgrade,
Downgrade,
ApplyOffer,
NotSupported(String),
}Expand description
The reason for the Advanced Commerce request.
Variants
Upgrade
Downgrade
ApplyOffer
NotSupported(String)
A value the App Store sent that this version of the library does not support, preserved as received.