pub struct DecodedRealtimeRequestBody {
pub original_transaction_id: String,
pub app_apple_id: i64,
pub product_id: String,
pub user_locale: String,
pub request_identifier: Uuid,
pub signed_date: DateTime<Utc>,
pub environment: Environment,
}Expand description
The decoded request body the App Store sends to your server to request a real-time retention message.
Fields
original_transaction_id: StringThe original transaction identifier of the customer’s subscription.
app_apple_id: i64The unique identifier of the app in the App Store.
product_id: StringThe unique identifier of the auto-renewable subscription.
user_locale: StringThe device’s locale.
request_identifier: UuidA UUID the App Store server creates to uniquely identify each request.
signed_date: DateTime<Utc>The UNIX time, in milliseconds, that the App Store signed the JSON Web Signature (JWS) data.
environment: EnvironmentThe server environment, either sandbox or production.