pub enum ExtendReasonCode {
Undeclared,
CustomerSatisfaction,
Other,
ServiceIssueOrOutage,
NotSupported(i64),
}Expand description
The code that represents the reason for the subscription-renewal-date extension.
Variants
Undeclared
CustomerSatisfaction
Other
ServiceIssueOrOutage
NotSupported(i64)
A value the App Store sent that this version of the library does not support, preserved as received.