pub enum PlayTime {
Undeclared,
ZeroToFiveMinutes,
FiveToSixtyMinutes,
OneToSixHours,
SixHoursToTwentyFourHours,
OneDayToFourDays,
FourDaysToSixteenDays,
OverSixteenDays,
NotSupported(i64),
}Expand description
A value that indicates the amount of time that the customer used the app.
Variants
Undeclared
ZeroToFiveMinutes
FiveToSixtyMinutes
OneToSixHours
SixHoursToTwentyFourHours
OneDayToFourDays
FourDaysToSixteenDays
OverSixteenDays
NotSupported(i64)
A value the App Store sent that this version of the library does not support, preserved as received.