pub enum Status {
Active,
Expired,
BillingRetry,
BillingGracePeriod,
Revoked,
NotSupported(i64),
}Expand description
The status of an auto-renewable subscription.
Variants
Active
Expired
BillingRetry
BillingGracePeriod
Revoked
NotSupported(i64)
A value the App Store sent that this version of the library does not support, preserved as received.
Implementations